package Catalyst::Plugin::AutoCRUD::Model::DBIC;
{
  $Catalyst::Plugin::AutoCRUD::Model::DBIC::VERSION = '2.112890_002';
}

use strict;
use warnings FATAL => 'all';

use base 'Catalyst::Model::DBIC::Schema';

1;
__END__
