html {
    padding-right: 0px;
    padding-left: 0px; 
    padding-bottom: 0px; 
    margin: 0px; 
    padding-top: 0px
}
body {
    font-family: "Bitstream Vera Sans", "Trebuchet MS",
                  Verdana, Tahoma, Arial, helvetica,
                  sans-serif;
    background-color: #EEEEEE;
    padding-right: 0px; 
    padding-left: 0px; 
    padding-bottom: 0px;
    margin: 0px; padding-top: 0px;
}

